'use server';

import 'server-only';
import { createServerClient } from '@/utils/supabase';
import { NextResponse } from 'next/server';

export const GET = async (request: Request) => {
  const requestUrl = new URL(request.url);
  const code = requestUrl.searchParams.get('code');
  const token = requestUrl.searchParams.get('token');
  const type = requestUrl.searchParams.get('type');
  const origin = requestUrl.origin;
  const redirectTo = requestUrl.searchParams.get('redirect_to')?.toString();

  const supabase = await createServerClient();

  if (token && type) {
    try {
      if (type === 'signup') {
        // Confirm email signup
        const { error } = await supabase.auth.verifyOtp({
          token_hash: token,
          type: 'signup',
        });
        
        if (error) {
          console.error('Email confirmation error:', error);
          return NextResponse.redirect(`${origin}/sign-in?error=Invalid or expired confirmation link`);
        }
      } else if (type === 'recovery') {
        // Handle password recovery
        const { error } = await supabase.auth.verifyOtp({
          token_hash: token,
          type: 'recovery',
        });
        
        if (error) {
          console.error('Password recovery error:', error);
          return NextResponse.redirect(`${origin}/sign-in?error=Invalid or expired reset link`);
        } else {
          return NextResponse.redirect(`${origin}/reset-password`);
        }
      } else if (type === 'email_change') {
        // Handle email change
        const { error } = await supabase.auth.verifyOtp({
          token_hash: token,
          type: 'email_change',
        });
        
        if (error) {
          console.error('Email change error:', error);
          return NextResponse.redirect(`${origin}/profile?error=Invalid or expired email change link`);
        }
      }
    } catch (error) {
      console.error('Verification error:', error);
      return NextResponse.redirect(`${origin}/sign-in?error=Verification failed`);
    }
  }

  // Handle code-based flow (OAuth, etc.)
  if (code) {
    await supabase.auth.exchangeCodeForSession(code);
  }

  // Handle redirect
  if (redirectTo) {
    try {
      new URL(redirectTo);
      return NextResponse.redirect(redirectTo);
    } catch {
      return NextResponse.redirect(`${origin}${redirectTo}`);
    }
  }

  return NextResponse.redirect(origin);
}
