'use client';
import Link from 'next/link';
import { signIn } from '@/lib/actions';
import { SubmitButton } from '@/components/default';
import { Input, Label } from '@/components/ui';
import { useRouter } from 'next/navigation';
import { useAuth } from '@/components/context/auth';
import { useEffect } from 'react';

const Login = () => {
  const router = useRouter();
  const { isAuthenticated, refreshUserData } = useAuth();

  // Redirect if already authenticated
  useEffect(() => {
    if (isAuthenticated) {
      router.push('/');
    }
  }, [isAuthenticated, router]);

  const handleSignIn = async (formData: FormData) => {
    const result = await signIn(formData);
    if (result?.success) {
      await refreshUserData();
      router.push('/');
    }
  };

  return (
    <form className='flex-1 flex flex-col min-w-64'>
      <h1 className='text-2xl font-medium'>Sign in</h1>
      <p className='text-sm text-foreground'>
        Don&apos;t have an account?{' '}
        <Link className='text-foreground font-medium underline' href='/sign-up'>
          Sign up
        </Link>
      </p>
      <div className='flex flex-col gap-2 [&>input]:mb-3 mt-8'>
        <Label htmlFor='email'>Email</Label>
        <Input name='email' placeholder='you@example.com' required />
        <div className='flex justify-between items-center'>
          <Label htmlFor='password'>Password</Label>
          <Link
            className='text-xs text-foreground underline'
            href='/forgot-password'
          >
            Forgot Password?
          </Link>
        </div>
        <Input
          type='password'
          name='password'
          placeholder='Your password'
          required
        />
        <SubmitButton pendingText='Signing In...' formAction={handleSignIn}>
          Sign in
        </SubmitButton>
      </div>
    </form>
  );
};

export default Login;
