import { type Metadata } from 'next';
import '@/styles/globals.css';
import { Geist } from 'next/font/google';
import { cn } from '@/lib/utils';
import { ThemeProvider } from '@/components/context/theme';
import { AuthProvider } from '@/components/context/auth'
import Navigation from '@/components/default/navigation';
import Footer from '@/components/default/footer';
import { Toaster } from '@/components/ui';

export const metadata: Metadata = {
  title: 'T3 Template with Supabase',
  description: 'Generated by create-t3-app',
  icons: [
    {
      rel: 'icon',
      url: '/images/favicon.ico',
    },
    {
      rel: 'icon',
      type: 'image/png',
      sizes: '32x32',
      url: '/images/favicon.png',
    },
    {
      rel: 'apple-touch-icon',
      url: '/images/appicon.png',
    },
  ],
};

const geist = Geist({
  subsets: ['latin'],
  variable: '--font-geist-sans',
});

const RootLayout = ({ children }: Readonly<{ children: React.ReactNode }>) => {
  return (
    <html lang='en' className={`${geist.variable}`} suppressHydrationWarning>
      <body
        className={cn('bg-background text-foreground font-sans antialiased')}
      >
        <ThemeProvider
          attribute='class'
          defaultTheme='system'
          enableSystem
          disableTransitionOnChange
        >
          <AuthProvider>
            <main className='min-h-screen flex flex-col items-center'>
              <div className='flex-1 w-full flex flex-col gap-20 items-center'>
                <Navigation />
                <div className='flex flex-col gap-20 max-w-5xl p-5 w-full'>
                  {children}
                </div>
              </div>
              <Footer />
            </main>
            <Toaster />
          </AuthProvider>
        </ThemeProvider>
      </body>
    </html>
  );
};
export default RootLayout;
